/* -*- buffer-read-only: t -*-
 *
 *      Copyright (c) 1996-1999 Malcolm Beattie
 *      Copyright (c) 2008,2009,2010,2011,2012 Reini Urban
 *      Copyright (c) 2011-2016 cPanel Inc
 *
 *      You may distribute under the terms of either the GNU General Public
 *      License or the Artistic License, as specified in the README file.
 *
 */
/*
 * This file is autogenerated from bytecode.pl. Changes made here will be lost.
 * It is specific for Perl 5.032000 only.
 */

#define PERL_NO_GET_CONTEXT
#include "EXTERN.h"
#include "perl.h"
#define NO_XSLOCKS
#include "XSUB.h"
#if PERL_VERSION < 8
  #define NEED_sv_2pv_flags
  #include "ppport.h"
#endif

/* Change 31252: move PL_tokenbuf into the PL_parser struct */
#if (PERL_VERSION > 8) && (!defined(PL_tokenbuf))
  #define PL_tokenbuf		(PL_parser->tokenbuf)
#endif
#if (PERL_VERSION < 8) && (!defined(DEBUG_v))
  #define DEBUG_v(a) DEBUG_f(a)
#endif

#include "byterun.h"
#include "bytecode.h"

struct byteloader_header bl_header;

#if 0
static const int optype_size[] = {
    sizeof(OP),
    sizeof(UNOP),
    sizeof(BINOP),
    sizeof(LOGOP),
    sizeof(LISTOP),
    sizeof(PMOP),
    sizeof(SVOP),
    sizeof(PADOP),
    sizeof(PVOP),
    sizeof(LOOP),
    sizeof(COP),
    sizeof(METHOP),
    sizeof(UNOP_AUX)
};
#endif

void *
bset_obj_store(pTHX_ struct byteloader_state *bstate, void *obj, I32 ix)
{
    if (ix > bstate->bs_obj_list_fill) {
	Renew(bstate->bs_obj_list, ix + 32, void*);
	bstate->bs_obj_list_fill = ix + 31;
    }
    bstate->bs_obj_list[ix] = obj;
    return obj;
}

int bytecode_header_check(pTHX_ struct byteloader_state *bstate, U32 *isjit) {
    U32 sz = 0;
    strconst str;

    BGET_U32(sz); /* Magic: 'PLBC' or 'PLJC' */
    if (sz != 0x43424c50) {
        if (sz != 0x434a4c50) {
	    HEADER_FAIL1("bad magic (want 0x43424c50 PLBC or 0x434a4c50 PLJC, got %#x)",
		         (int)sz);
	} else {
	    *isjit = 1;
        }
    }
    BGET_strconst(str,80);	/* archname */
    my_strlcpy(bl_header.archname, str, 80);
    /* just warn. relaxed strictness, only check for ithread in archflag */
    if (strNEc(str, ARCHNAME)) {
	HEADER_WARN2("Different architecture %s, you have %s", str, ARCHNAME);
    }

    /* ByteLoader version strategy: Strict for 0.06_ development releases and 0.03-0.04.
       0.07 should be able to load 0.5 (5.8.1 CORE) */
    BGET_strconst(str,16);
    my_strlcpy(bl_header.version, str, 16);
    if (strNEc(str, VERSION)) {
        if ((strGT(str, "0.06") && strLT(str, "0.06_06")) /*|| strLT(str, "0.05")*/) {
	    HEADER_FAIL2("Incompatible bytecode version %s, you have %s",
		         str, VERSION);
        }
    }

    BGET_U32(sz); /* ivsize */
    bl_header.ivsize = sz;

    BGET_U32(sz); /* ptrsize */
    bl_header.ptrsize = sz;

    /* new since 0.06_03 */
    if (strGE(bl_header.version, "0.06_03")) {
        BGET_U32(sz); /* longsize */
        bl_header.longsize = sz;
    } else {
        bl_header.longsize = LONGSIZE;
    }

    if (strGT(bl_header.version, "0.06") || strEQc(bl_header.version, "0.04"))
    {   /* added again with 0.06_01 */
	/* config.h BYTEORDER: 0x1234 of length longsize, not ivsize */
	char supported[16];
	/* Note: perl's $Config{byteorder} is wrong with 64int.
	   Bug in Config.pm:921 my $s = $Config{ivsize}; => my $s = $Config{longsize};
	*/
	sprintf(supported, "%x", BYTEORDER);
	BGET_strconst(str, 16); /* optional 0x prefix, 12345678 or 1234 */
	if (str[0] == 0x30 && str[1] == 0x78) { /* skip '0x' */
	    str++; str++;
	}
	my_strlcpy(bl_header.byteorder, str, 16);
	if (strNE(str, supported)) {
	    /* swab only if same length. 1234 => 4321, 12345678 => 87654321 */
	    if (strlen(str) == strlen(supported)) {
		bget_swab = 1;
		HEADER_WARN2("EXPERIMENTAL byteorder conversion: .plc=%s, perl=%s",
			     str, supported);
	    } else {
		HEADER_FAIL2("Unsupported byteorder conversion: .plc=%s, perl=%s",
			     str, supported);
	    }
	}
    }

    /* swab byteorder */
    if (bget_swab) {
	bl_header.ivsize = _swab_32_(bl_header.ivsize);
	bl_header.ptrsize = _swab_32_(bl_header.ptrsize);
        if (bl_header.longsize != LONGSIZE) {
	    bl_header.longsize = _swab_32_(bl_header.longsize);
        }
    }

#ifdef USE_ITHREADS
# define HAVE_ITHREADS_I 1
#else
# define HAVE_ITHREADS_I 0
#endif
#ifdef MULTIPLICITY
# define HAVE_MULTIPLICITY_I 2
#else
# define HAVE_MULTIPLICITY_I 0
#endif
    if (strGE(bl_header.version, "0.06_05")) {
        BGET_U16(sz); /* archflag */
        bl_header.archflag = sz;
        if ((sz & 1) != HAVE_ITHREADS_I) {
	    HEADER_FAIL2("Wrong USE_ITHREADS. Bytecode: %s, System: %s)",
		         bl_header.archflag & 1 ? "yes" : "no",
			 HAVE_ITHREADS_I ? "yes" : "no");
	}
	if (strGE(bl_header.version, "0.08")) {		
 	    if ((sz & 2) != HAVE_MULTIPLICITY_I) {
	        HEADER_FAIL2("Wrong MULTIPLICITY. Bytecode: %s, System: %s)",
		             bl_header.archflag & 2 ? "yes" : "no",
			     HAVE_MULTIPLICITY_I ? "yes" : "no");
	    }
	}
    }

    if (bl_header.ivsize != IVSIZE) {
	HEADER_WARN("different IVSIZE");
        if ((bl_header.ivsize != 4) && (bl_header.ivsize != 8))
	    HEADER_FAIL1("unsupported IVSIZE %d", bl_header.ivsize);
    }
    if (bl_header.ptrsize != PTRSIZE) {
	HEADER_WARN("different PTRSIZE");
        if ((bl_header.ptrsize != 4) && (bl_header.ptrsize != 8))
	    HEADER_FAIL1("unsupported PTRSIZE %d", bl_header.ptrsize);
    }
    if (strGE(bl_header.version, "0.06_03")) {
        if (bl_header.longsize != LONGSIZE) {
	    HEADER_WARN("different LONGSIZE");
            if ((bl_header.longsize != 4) && (bl_header.longsize != 8))
	        HEADER_FAIL1("unsupported LONGSIZE %d", bl_header.longsize);
      }
    }
    if (strGE(bl_header.version, "0.06_06")) {
        BGET_strconst(str, 16);
        my_strlcpy(bl_header.perlversion, str, 16);
    } else {
        *bl_header.perlversion = 0;
    }

    return 1;
}

int
byterun(pTHX_ struct byteloader_state *bstate)
{
    register int insn;
    U32 isjit = 0;
    U32 ix;
    SV *specialsv_list[8];

    bytecode_header_check(aTHX_ bstate, &isjit); /* croak if incorrect platform,
						    set isjit on PLJC magic header */
    if (isjit) {
	Perl_croak(aTHX_ "PLJC-magic: No JIT support yet\n");
        return 0; /*jitrun(aTHX_ &bstate);*/
    } else {
        New(0, bstate->bs_obj_list, 32, void*); /* set op objlist */
        bstate->bs_obj_list_fill = 31;
        bstate->bs_obj_list[0] = NULL;          /* first is always Null */
        bstate->bs_ix = 1;
	CopLINE(PL_curcop) = bstate->bs_fdata->next_out;
	DEBUG_l( Perl_deb(aTHX_ "(bstate.bs_fdata.idx %d)\n", bstate->bs_fdata->idx));
	DEBUG_l( Perl_deb(aTHX_ "(bstate.bs_fdata.next_out %d)\n", bstate->bs_fdata->next_out));
	DEBUG_l( Perl_deb(aTHX_ "(bstate.bs_fdata.datasv %p:\"%s\")\n", bstate->bs_fdata->datasv,
				 SvPV_nolen(bstate->bs_fdata->datasv)));

        specialsv_list[0] = Nullsv;
        specialsv_list[1] = &PL_sv_undef;
        specialsv_list[2] = &PL_sv_yes;
        specialsv_list[3] = &PL_sv_no;
        specialsv_list[4] = (SV*)pWARN_ALL;
        specialsv_list[5] = (SV*)pWARN_NONE;
        specialsv_list[6] = (SV*)pWARN_STD;
        specialsv_list[7] = &PL_sv_zero;

        while ((insn = BGET_FGETC()) != EOF) {
	    CopLINE(PL_curcop) = bstate->bs_fdata->next_out;
	    switch (insn) {
	  case INSN_COMMENT:		/* 35 */
	    {
		comment_t arg;
		BGET_comment_t(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) comment comment_t:%d\n",
				insn, (int)arg));
		PERL_UNUSED_VAR(arg);
		DEBUG_v(Perl_deb(aTHX_ "	   arg = %d;\n", (int)arg));
		break;
	    }
	  case INSN_NOP:		/* 10 */
	    {
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) nop\n", insn));
		break;
	    }
	  case INSN_RET:		/* 0 */
	    {
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) ret\n", insn));
		BSET_ret(none);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_ret(none)\n"));
		break;
	    }
	  case INSN_LDSV:		/* 1 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) ldsv svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		bstate->u.bs_sv = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   bstate->u.bs_sv = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_LDOP:		/* 2 */
	    {
		opindex arg;
		BGET_opindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) ldop opindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		PL_op = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   PL_op = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_STSV:		/* 3 */
	    {
		U32 arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) stsv U32:%u\n",
				insn, (int)arg));
		BSET_OBJ_STORE(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_OBJ_STORE(bstate->u.bs_sv, arg)\n"));
		break;
	    }
	  case INSN_STOP:		/* 4 */
	    {
		U32 arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) stop U32:%u\n",
				insn, (int)arg));
		BSET_OBJ_STORE(PL_op, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_OBJ_STORE(PL_op, arg)\n"));
		break;
	    }
	  case INSN_STPV:		/* 5 */
	    {
		U32 arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) stpv U32:%u\n",
				insn, (int)arg));
		BSET_stpv(bstate->bs_pv.pv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_stpv(bstate->bs_pv.pv, %u)\n",
				(int)arg));
		break;
	    }
	  case INSN_LDSPECSV:		/* 6 */
	    {
		U8 arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) ldspecsv U8:%u\n",
				insn, (int)arg));
		BSET_ldspecsv(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_ldspecsv(bstate->u.bs_sv, %u)\n",
				(int)arg));
		break;
	    }
	  case INSN_LDSPECSVX:		/* 7 */
	    {
		U8 arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) ldspecsvx U8:%u\n",
				insn, (int)arg));
		BSET_ldspecsvx(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_ldspecsvx(bstate->u.bs_sv, %u ix:%d)\n",
				(int)arg, bstate->bs_ix-1));
		break;
	    }
	  case INSN_NEWSV:		/* 8 */
	    {
		U8 arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) newsv U8:%u\n",
				insn, (int)arg));
		BSET_newsv(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_newsv(bstate->u.bs_sv, %u)\n",
				(int)arg));
		break;
	    }
	  case INSN_NEWSVX:		/* 9 */
	    {
		U32 arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) newsvx U32:%u\n",
				insn, (int)arg));
		BSET_newsvx(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_newsvx(bstate->u.bs_sv, %u ix:%d)\n",
				(int)arg, bstate->bs_ix-1));
		break;
	    }
	  case INSN_NEWOP:		/* 11 */
	    {
		U8 arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) newop U8:%u\n",
				insn, (int)arg));
		DEBUG_v(Perl_deb(aTHX_ "	   [%s %d]\n", PL_op_name[arg>>7], bstate->bs_ix));
		BSET_newop(PL_op, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_newop(PL_op, %u)\n",
				(int)arg));
		break;
	    }
	  case INSN_NEWOPX:		/* 12 */
	    {
		U16 arg;
		BGET_U16(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) newopx U16:%u\n",
				insn, (int)arg));
		DEBUG_v(Perl_deb(aTHX_ "	   [%s %d]\n", PL_op_name[arg>>7], bstate->bs_ix));
		BSET_newopx(PL_op, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_newopx(PL_op, %u ix:%d)\n",
				(int)arg, bstate->bs_ix-1));
		break;
	    }
	  case INSN_NEWOPN:		/* 13 */
	    {
		U8 arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) newopn U8:%u\n",
				insn, (int)arg));
		BSET_newopn(PL_op, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_newopn(PL_op, %u)\n",
				(int)arg));
		break;
	    }
	  case INSN_NEWPV:		/* 14 */
	    {
		PV arg;
		BGET_PV(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) newpv (U32)PV:%d\n",
				insn, (int)arg));
		DEBUG_v(Perl_deb(aTHX_ "	   BGET_PV(arg) => \"%s\"\n", bstate->bs_pv.pv));
		break;
	    }
	  case INSN_PV_CUR:		/* 15 */
	    {
		STRLEN arg;
		BGET_PADOFFSET(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) pv_cur STRLEN:%d\n",
				insn, (int)arg));
		bstate->bs_pv.cur = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   bstate->bs_pv.cur = %d;\n", (int)arg));
		break;
	    }
	  case INSN_PV_FREE:		/* 16 */
	    {
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) pv_free\n", insn));
		BSET_pv_free(bstate->bs_pv);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_pv_free(bstate->bs_pv)\n"));
		break;
	    }
	  case INSN_SV_UPGRADE:		/* 17 */
	    {
		U8 arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) sv_upgrade U8:%u\n",
				insn, (int)arg));
		BSET_sv_upgrade(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_sv_upgrade(bstate->u.bs_sv, %u)\n",
				(int)arg));
		break;
	    }
	  case INSN_SV_REFCNT:		/* 18 */
	    {
		U32 arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) sv_refcnt U32:%u\n",
				insn, (int)arg));
		SvREFCNT(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   SvREFCNT(bstate->u.bs_sv) = %u;\n", (int)arg));
		break;
	    }
	  case INSN_SV_REFCNT_ADD:		/* 19 */
	    {
		I32 arg;
		BGET_I32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) sv_refcnt_add I32:%d\n",
				insn, (int)arg));
		BSET_sv_refcnt_add(SvREFCNT(bstate->u.bs_sv), arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_sv_refcnt_add(SvREFCNT(bstate->u.bs_sv), %d)\n",
				(int)arg));
		break;
	    }
	  case INSN_SV_FLAGS:		/* 20 */
	    {
		U32 arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) sv_flags U32:%u\n",
				insn, (int)arg));
		SvFLAGS(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   SvFLAGS(bstate->u.bs_sv) = %u;\n", (int)arg));
		break;
	    }
	  case INSN_XRV:		/* 21 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xrv svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_xrv(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_xrv(bstate->u.bs_sv, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_XPV:		/* 22 */
	    {
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xpv\n", insn));
		BSET_xpv(bstate->u.bs_sv);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_xpv(bstate->u.bs_sv)\n"));
		break;
	    }
	  case INSN_XPV_CUR:		/* 23 */
	    {
		STRLEN arg;
		BGET_PADOFFSET(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xpv_cur STRLEN:%d\n",
				insn, (int)arg));
		BSET_xpv_cur(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_xpv_cur(bstate->u.bs_sv, %d)\n",
				(int)arg));
		break;
	    }
	  case INSN_XPV_LEN:		/* 24 */
	    {
		STRLEN arg;
		BGET_PADOFFSET(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xpv_len STRLEN:%d\n",
				insn, (int)arg));
		BSET_xpv_len(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_xpv_len(bstate->u.bs_sv, %d)\n",
				(int)arg));
		break;
	    }
	  case INSN_XIV:		/* 25 */
	    {
		IV arg;
		BGET_IV(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xiv IV:%d\n",
				insn, (int)arg));
		BSET_xiv(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_xiv(bstate->u.bs_sv, %d)\n",
				(int)arg));
		break;
	    }
	  case INSN_XNV:		/* 26 */
	    {
		NV arg;
		BGET_NV(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xnv NV:%d\n",
				insn, (int)arg));
		BSET_xnv(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_xnv(bstate->u.bs_sv, %d)\n",
				(int)arg));
		break;
	    }
	  case INSN_XLV_TARGOFF:		/* 27 */
	    {
		STRLEN arg;
		BGET_PADOFFSET(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xlv_targoff STRLEN:%d\n",
				insn, (int)arg));
		LvTARGOFF(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   LvTARGOFF(bstate->u.bs_sv) = %d;\n", (int)arg));
		break;
	    }
	  case INSN_XLV_TARGLEN:		/* 28 */
	    {
		STRLEN arg;
		BGET_PADOFFSET(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xlv_targlen STRLEN:%d\n",
				insn, (int)arg));
		LvTARGLEN(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   LvTARGLEN(bstate->u.bs_sv) = %d;\n", (int)arg));
		break;
	    }
	  case INSN_XLV_TARG:		/* 29 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xlv_targ svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		LvTARG(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   LvTARG(bstate->u.bs_sv) = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_XLV_TYPE:		/* 30 */
	    {
		char arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xlv_type char:%u\n",
				insn, (int)arg));
		LvTYPE(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   LvTYPE(bstate->u.bs_sv) = %u;\n", (int)arg));
		break;
	    }
	  case INSN_XBM_USEFUL:		/* 31 */
	    {
		I32 arg;
		BGET_I32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xbm_useful I32:%d\n",
				insn, (int)arg));
		BmUSEFUL(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   BmUSEFUL(bstate->u.bs_sv) = %d;\n", (int)arg));
		break;
	    }
	  case 32:		/* 32 */
	    {
		U16 arg;
		PERL_UNUSED_VAR(arg);
		PerlIO_printf(Perl_error_log, "Unsupported bytecode instruction %d (XBM_PREVIOUS) at stream offset %d.\n",
	                                  insn, bstate->bs_fdata->next_out);
		if (force)
			BGET_U16(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xbm_previous U16:%u\n",
				insn, (int)arg));
		DEBUG_v(Perl_deb(aTHX_ "	   BmPREVIOUS(bstate->u.bs_sv) = %u;\n", (int)arg));
		break;
	    }
	  case 33:		/* 33 */
	    {
		U8 arg;
		PERL_UNUSED_VAR(arg);
		PerlIO_printf(Perl_error_log, "Unsupported bytecode instruction %d (XBM_RARE) at stream offset %d.\n",
	                                  insn, bstate->bs_fdata->next_out);
		if (force)
			BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xbm_rare U8:%u\n",
				insn, (int)arg));
		DEBUG_v(Perl_deb(aTHX_ "	   BmRARE(bstate->u.bs_sv) = %u;\n", (int)arg));
		break;
	    }
	  case INSN_XFM_LINES:		/* 34 */
	    {
		IV arg;
		BGET_IV(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xfm_lines IV:%d\n",
				insn, (int)arg));
		FmLINES(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   FmLINES(bstate->u.bs_sv) = %d;\n", (int)arg));
		break;
	    }
	  case INSN_XIO_LINES:		/* 36 */
	    {
		IV arg;
		BGET_IV(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xio_lines IV:%d\n",
				insn, (int)arg));
		IoLINES(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   IoLINES(bstate->u.bs_sv) = %d;\n", (int)arg));
		break;
	    }
	  case INSN_XIO_PAGE:		/* 37 */
	    {
		IV arg;
		BGET_IV(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xio_page IV:%d\n",
				insn, (int)arg));
		IoPAGE(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   IoPAGE(bstate->u.bs_sv) = %d;\n", (int)arg));
		break;
	    }
	  case INSN_XIO_PAGE_LEN:		/* 38 */
	    {
		IV arg;
		BGET_IV(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xio_page_len IV:%d\n",
				insn, (int)arg));
		IoPAGE_LEN(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   IoPAGE_LEN(bstate->u.bs_sv) = %d;\n", (int)arg));
		break;
	    }
	  case INSN_XIO_LINES_LEFT:		/* 39 */
	    {
		IV arg;
		BGET_IV(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xio_lines_left IV:%d\n",
				insn, (int)arg));
		IoLINES_LEFT(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   IoLINES_LEFT(bstate->u.bs_sv) = %d;\n", (int)arg));
		break;
	    }
	  case INSN_XIO_TOP_NAME:		/* 40 */
	    {
		pvindex arg;
		BGET_pvindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xio_top_name pvindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		IoTOP_NAME(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   IoTOP_NAME(bstate->u.bs_sv) = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_XIO_TOP_GV:		/* 41 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xio_top_gv svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		*(SV**)&IoTOP_GV(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   *(SV**)&IoTOP_GV(bstate->u.bs_sv) = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_XIO_FMT_NAME:		/* 42 */
	    {
		pvindex arg;
		BGET_pvindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xio_fmt_name pvindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		IoFMT_NAME(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   IoFMT_NAME(bstate->u.bs_sv) = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_XIO_FMT_GV:		/* 43 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xio_fmt_gv svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		*(SV**)&IoFMT_GV(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   *(SV**)&IoFMT_GV(bstate->u.bs_sv) = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_XIO_BOTTOM_NAME:		/* 44 */
	    {
		pvindex arg;
		BGET_pvindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xio_bottom_name pvindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		IoBOTTOM_NAME(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   IoBOTTOM_NAME(bstate->u.bs_sv) = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_XIO_BOTTOM_GV:		/* 45 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xio_bottom_gv svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		*(SV**)&IoBOTTOM_GV(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   *(SV**)&IoBOTTOM_GV(bstate->u.bs_sv) = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case 46:		/* 46 */
	    {
		short arg;
		PERL_UNUSED_VAR(arg);
		PerlIO_printf(Perl_error_log, "Unsupported bytecode instruction %d (XIO_SUBPROCESS) at stream offset %d.\n",
	                                  insn, bstate->bs_fdata->next_out);
		if (force)
			BGET_U16(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xio_subprocess short:%u\n",
				insn, (int)arg));
		DEBUG_v(Perl_deb(aTHX_ "	   IoSUBPROCESS(bstate->u.bs_sv) = %u;\n", (int)arg));
		break;
	    }
	  case INSN_XIO_TYPE:		/* 47 */
	    {
		char arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xio_type char:%u\n",
				insn, (int)arg));
		IoTYPE(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   IoTYPE(bstate->u.bs_sv) = %u;\n", (int)arg));
		break;
	    }
	  case INSN_XIO_FLAGS:		/* 48 */
	    {
		char arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xio_flags char:%u\n",
				insn, (int)arg));
		IoFLAGS(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   IoFLAGS(bstate->u.bs_sv) = %u;\n", (int)arg));
		break;
	    }
	  case INSN_XCV_XSUBANY:		/* 49 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xcv_xsubany svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		*(SV**)&CvXSUBANY(bstate->u.bs_sv).any_ptr = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   *(SV**)&CvXSUBANY(bstate->u.bs_sv).any_ptr = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_XCV_STASH:		/* 50 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xcv_stash svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_xcv_stash(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_xcv_stash(bstate->u.bs_sv, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_XCV_START:		/* 51 */
	    {
		opindex arg;
		BGET_opindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xcv_start opindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		CvSTART(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   CvSTART(bstate->u.bs_sv) = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_XCV_ROOT:		/* 52 */
	    {
		opindex arg;
		BGET_opindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xcv_root opindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		CvROOT(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   CvROOT(bstate->u.bs_sv) = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_XCV_GV:		/* 53 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xcv_gv svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_xcv_gv(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_xcv_gv(bstate->u.bs_sv, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_XCV_FILE:		/* 54 */
	    {
		pvindex arg;
		BGET_pvindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xcv_file pvindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		CvFILE(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   CvFILE(bstate->u.bs_sv) = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_XCV_DEPTH:		/* 55 */
	    {
		long arg;
		BGET_long(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xcv_depth long:%d\n",
				insn, (int)arg));
		CvDEPTH(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   CvDEPTH(bstate->u.bs_sv) = %d;\n", (int)arg));
		break;
	    }
	  case INSN_XCV_PADLIST:		/* 56 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xcv_padlist svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		*(SV**)&CvPADLIST(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   *(SV**)&CvPADLIST(bstate->u.bs_sv) = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_XCV_OUTSIDE:		/* 57 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xcv_outside svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		*(SV**)&CvOUTSIDE(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   *(SV**)&CvOUTSIDE(bstate->u.bs_sv) = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_XCV_OUTSIDE_SEQ:		/* 58 */
	    {
		U32 arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xcv_outside_seq U32:%u\n",
				insn, (int)arg));
		CvOUTSIDE_SEQ(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   CvOUTSIDE_SEQ(bstate->u.bs_sv) = %u;\n", (int)arg));
		break;
	    }
	  case INSN_XCV_FLAGS:		/* 59 */
	    {
		U32 arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xcv_flags U32:%u\n",
				insn, (int)arg));
		CvFLAGS(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   CvFLAGS(bstate->u.bs_sv) = %u;\n", (int)arg));
		break;
	    }
	  case INSN_AV_EXTEND:		/* 60 */
	    {
		SSize_t arg;
		BGET_PADOFFSET(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) av_extend SSize_t:%d\n",
				insn, (int)arg));
		BSET_av_extend(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_av_extend(bstate->u.bs_sv, %d)\n",
				(int)arg));
		break;
	    }
	  case INSN_AV_PUSHX:		/* 61 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) av_pushx svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_av_pushx(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_av_pushx(bstate->u.bs_sv, 0x%lx ix:%d)\n",
				PTR2UV(arg), bstate->bs_ix-1));
		break;
	    }
	  case 62:		/* 62 */
	    {
		svindex arg;
		PERL_UNUSED_VAR(arg);
		PerlIO_printf(Perl_error_log, "Unsupported bytecode instruction %d (AV_PUSH) at stream offset %d.\n",
	                                  insn, bstate->bs_fdata->next_out);
		if (force)
			BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) av_push svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		if (force)
			BSET_av_push(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_av_push(bstate->u.bs_sv, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case 63:		/* 63 */
	    {
		SSize_t arg;
		PERL_UNUSED_VAR(arg);
		PerlIO_printf(Perl_error_log, "Unsupported bytecode instruction %d (XAV_FILL) at stream offset %d.\n",
	                                  insn, bstate->bs_fdata->next_out);
		if (force)
			BGET_PADOFFSET(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xav_fill SSize_t:%d\n",
				insn, (int)arg));
		DEBUG_v(Perl_deb(aTHX_ "	   AvFILLp(bstate->u.bs_sv) = %d;\n", (int)arg));
		break;
	    }
	  case 64:		/* 64 */
	    {
		SSize_t arg;
		PERL_UNUSED_VAR(arg);
		PerlIO_printf(Perl_error_log, "Unsupported bytecode instruction %d (XAV_MAX) at stream offset %d.\n",
	                                  insn, bstate->bs_fdata->next_out);
		if (force)
			BGET_PADOFFSET(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xav_max SSize_t:%d\n",
				insn, (int)arg));
		DEBUG_v(Perl_deb(aTHX_ "	   AvMAX(bstate->u.bs_sv) = %d;\n", (int)arg));
		break;
	    }
	  case 66:		/* 66 */
	    {
		I32 arg;
		PERL_UNUSED_VAR(arg);
		PerlIO_printf(Perl_error_log, "Unsupported bytecode instruction %d (XHV_RITER) at stream offset %d.\n",
	                                  insn, bstate->bs_fdata->next_out);
		if (force)
			BGET_I32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xhv_riter I32:%d\n",
				insn, (int)arg));
		DEBUG_v(Perl_deb(aTHX_ "	   HvRITER(bstate->u.bs_sv) = %d;\n", (int)arg));
		break;
	    }
	  case INSN_XHV_NAME:		/* 67 */
	    {
		pvindex arg;
		BGET_pvindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xhv_name pvindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_xhv_name(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_xhv_name(bstate->u.bs_sv, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case 68:		/* 68 */
	    {
		opindex arg;
		PERL_UNUSED_VAR(arg);
		PerlIO_printf(Perl_error_log, "Unsupported bytecode instruction %d (XHV_PMROOT) at stream offset %d.\n",
	                                  insn, bstate->bs_fdata->next_out);
		if (force)
			BGET_opindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xhv_pmroot opindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		DEBUG_v(Perl_deb(aTHX_ "	   *(OP**)&HvPMROOT(bstate->u.bs_sv) = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_HV_STORE:		/* 69 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) hv_store svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_hv_store(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_hv_store(bstate->u.bs_sv, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_SV_MAGIC:		/* 70 */
	    {
		char arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) sv_magic char:%u\n",
				insn, (int)arg));
		BSET_sv_magic(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_sv_magic(bstate->u.bs_sv, %u)\n",
				(int)arg));
		break;
	    }
	  case INSN_MG_OBJ:		/* 71 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) mg_obj svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		SvMAGIC(bstate->u.bs_sv)->mg_obj = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   SvMAGIC(bstate->u.bs_sv)->mg_obj = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_MG_PRIVATE:		/* 72 */
	    {
		U16 arg;
		BGET_U16(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) mg_private U16:%u\n",
				insn, (int)arg));
		SvMAGIC(bstate->u.bs_sv)->mg_private = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   SvMAGIC(bstate->u.bs_sv)->mg_private = %u;\n", (int)arg));
		break;
	    }
	  case INSN_MG_FLAGS:		/* 73 */
	    {
		U8 arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) mg_flags U8:%u\n",
				insn, (int)arg));
		SvMAGIC(bstate->u.bs_sv)->mg_flags = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   SvMAGIC(bstate->u.bs_sv)->mg_flags = %u;\n", (int)arg));
		break;
	    }
	  case INSN_MG_NAME:		/* 74 */
	    {
		pvcontents arg;
		BGET_pvcontents(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) mg_name pvcontents:\"%s\"\n",
				insn, (char*)arg));
		BSET_mg_name(SvMAGIC(bstate->u.bs_sv), arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_mg_name(SvMAGIC(bstate->u.bs_sv), \"%s\")\n",
				(char*)arg));
		break;
	    }
	  case INSN_MG_NAMEX:		/* 75 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) mg_namex svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_mg_namex(SvMAGIC(bstate->u.bs_sv), arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_mg_namex(SvMAGIC(bstate->u.bs_sv), 0x%lx ix:%d)\n",
				PTR2UV(arg), bstate->bs_ix-1));
		break;
	    }
	  case INSN_XMG_STASH:		/* 76 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xmg_stash svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_xmg_stash(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_xmg_stash(bstate->u.bs_sv, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_GV_FETCHPV:		/* 77 */
	    {
		strconst arg;
		BGET_strconst(arg, 0);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) gv_fetchpv strconst:\"%s\"\n",
				insn, (char*)arg));
		BSET_gv_fetchpv(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_gv_fetchpv(bstate->u.bs_sv, \"%s\")\n",
				(char*)arg));
		break;
	    }
	  case INSN_GV_FETCHPVX:		/* 78 */
	    {
		strconst arg;
		BGET_strconst(arg, 0);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) gv_fetchpvx strconst:\"%s\"\n",
				insn, (char*)arg));
		BSET_gv_fetchpvx(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_gv_fetchpvx(bstate->u.bs_sv, \"%s\" ix:%d)\n",
				(char*)arg, bstate->bs_ix-1));
		break;
	    }
	  case INSN_GV_STASHPV:		/* 79 */
	    {
		strconst arg;
		BGET_strconst(arg, 0);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) gv_stashpv strconst:\"%s\"\n",
				insn, (char*)arg));
		BSET_gv_stashpv(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_gv_stashpv(bstate->u.bs_sv, \"%s\")\n",
				(char*)arg));
		break;
	    }
	  case INSN_GV_STASHPVX:		/* 80 */
	    {
		strconst arg;
		BGET_strconst(arg, 0);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) gv_stashpvx strconst:\"%s\"\n",
				insn, (char*)arg));
		BSET_gv_stashpvx(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_gv_stashpvx(bstate->u.bs_sv, \"%s\" ix:%d)\n",
				(char*)arg, bstate->bs_ix-1));
		break;
	    }
	  case INSN_GP_SV:		/* 81 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) gp_sv svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_gp_sv(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_gp_sv(bstate->u.bs_sv, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_GP_REFCNT:		/* 82 */
	    {
		U32 arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) gp_refcnt U32:%u\n",
				insn, (int)arg));
		GvREFCNT(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   GvREFCNT(bstate->u.bs_sv) = %u;\n", (int)arg));
		break;
	    }
	  case INSN_GP_REFCNT_ADD:		/* 83 */
	    {
		I32 arg;
		BGET_I32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) gp_refcnt_add I32:%d\n",
				insn, (int)arg));
		BSET_gp_refcnt_add(GvREFCNT(bstate->u.bs_sv), arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_gp_refcnt_add(GvREFCNT(bstate->u.bs_sv), %d)\n",
				(int)arg));
		break;
	    }
	  case INSN_GP_AV:		/* 84 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) gp_av svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		*(SV**)&GvAV(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   *(SV**)&GvAV(bstate->u.bs_sv) = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_GP_HV:		/* 85 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) gp_hv svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		*(SV**)&GvHV(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   *(SV**)&GvHV(bstate->u.bs_sv) = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_GP_CV:		/* 86 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) gp_cv svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_gp_cv(*(SV**)&GvCV(bstate->u.bs_sv), arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_gp_cv(*(SV**)&GvCV(bstate->u.bs_sv), 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_GP_FILE:		/* 87 */
	    {
		pvindex arg;
		BGET_pvindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) gp_file pvindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_gp_file(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_gp_file(bstate->u.bs_sv, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_GP_IO:		/* 88 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) gp_io svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		*(SV**)&GvIOp(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   *(SV**)&GvIOp(bstate->u.bs_sv) = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_GP_FORM:		/* 89 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) gp_form svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		*(SV**)&GvFORM(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   *(SV**)&GvFORM(bstate->u.bs_sv) = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_GP_CVGEN:		/* 90 */
	    {
		U32 arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) gp_cvgen U32:%u\n",
				insn, (int)arg));
		GvCVGEN(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   GvCVGEN(bstate->u.bs_sv) = %u;\n", (int)arg));
		break;
	    }
	  case INSN_GP_LINE:		/* 91 */
	    {
		line_t arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) gp_line line_t:%u\n",
				insn, (int)arg));
		GvLINE(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   GvLINE(bstate->u.bs_sv) = %u;\n", (int)arg));
		break;
	    }
	  case INSN_GP_SHARE:		/* 92 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) gp_share svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_gp_share(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_gp_share(bstate->u.bs_sv, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_XGV_FLAGS:		/* 93 */
	    {
		SSize_t arg;
		BGET_PADOFFSET(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xgv_flags SSize_t:%d\n",
				insn, (int)arg));
		GvFLAGS(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   GvFLAGS(bstate->u.bs_sv) = %d;\n", (int)arg));
		break;
	    }
	  case INSN_OP_NEXT:		/* 94 */
	    {
		opindex arg;
		BGET_opindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_next opindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		PL_op->op_next = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   PL_op->op_next = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_OP_SIBLING:		/* 95 */
	    {
		opindex arg;
		BGET_opindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_sibling opindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_op_sibling(PL_op, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_op_sibling(PL_op, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_OP_PPADDR:		/* 96 */
	    {
		strconst arg;
		BGET_strconst(arg, 0);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_ppaddr strconst:\"%s\"\n",
				insn, (char*)arg));
		BSET_op_ppaddr(PL_op->op_ppaddr, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_op_ppaddr(PL_op->op_ppaddr, \"%s\")\n",
				(char*)arg));
		break;
	    }
	  case INSN_OP_TARG:		/* 97 */
	    {
		PADOFFSET arg;
		BGET_PADOFFSET(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_targ PADOFFSET:%d\n",
				insn, (int)arg));
		PL_op->op_targ = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   PL_op->op_targ = %d;\n", (int)arg));
		break;
	    }
	  case INSN_OP_TYPE:		/* 98 */
	    {
		OPCODE arg;
		BGET_U16(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_type OPCODE:%u\n",
				insn, (int)arg));
		BSET_op_type(PL_op, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_op_type(PL_op, %u)\n",
				(int)arg));
		break;
	    }
	  case INSN_OP_OPT:		/* 99 */
	    {
		U8 arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_opt U8:%u\n",
				insn, (int)arg));
		PL_op->op_opt = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   PL_op->op_opt = %u;\n", (int)arg));
		break;
	    }
	  case INSN_OP_FLAGS:		/* 100 */
	    {
		U8 arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_flags U8:%u\n",
				insn, (int)arg));
		PL_op->op_flags = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   PL_op->op_flags = %u;\n", (int)arg));
		break;
	    }
	  case INSN_OP_PRIVATE:		/* 101 */
	    {
		U8 arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_private U8:%u\n",
				insn, (int)arg));
		PL_op->op_private = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   PL_op->op_private = %u;\n", (int)arg));
		break;
	    }
	  case INSN_OP_FIRST:		/* 102 */
	    {
		opindex arg;
		BGET_opindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_first opindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		cUNOP->op_first = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   cUNOP->op_first = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_OP_LAST:		/* 103 */
	    {
		opindex arg;
		BGET_opindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_last opindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		cBINOP->op_last = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   cBINOP->op_last = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_OP_OTHER:		/* 104 */
	    {
		opindex arg;
		BGET_opindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_other opindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		cLOGOP->op_other = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   cLOGOP->op_other = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_OP_PMREPLROOT:		/* 105 */
	    {
		opindex arg;
		BGET_opindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_pmreplroot opindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		(cPMOP->op_pmreplrootu).op_pmreplroot = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   (cPMOP->op_pmreplrootu).op_pmreplroot = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_OP_PMREPLSTART:		/* 106 */
	    {
		opindex arg;
		BGET_opindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_pmreplstart opindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		(cPMOP->op_pmstashstartu).op_pmreplstart = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   (cPMOP->op_pmstashstartu).op_pmreplstart = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_OP_PMSTASHPV:		/* 108 */
	    {
		pvindex arg;
		BGET_pvindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_pmstashpv pvindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_op_pmstashpv(cPMOP, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_op_pmstashpv(cPMOP, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_OP_PMREPLROOTPO:		/* 109 */
	    {
		PADOFFSET arg;
		BGET_PADOFFSET(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_pmreplrootpo (OP*)PADOFFSET:%d\n",
				insn, (int)arg));
		(cPMOP->op_pmreplrootu).op_pmreplroot = (OP*)arg;
		DEBUG_v(Perl_deb(aTHX_ "	   (cPMOP->op_pmreplrootu).op_pmreplroot = (OP*)%d;\n", (int)arg));
		break;
	    }
	  case INSN_PREGCOMP:		/* 112 */
	    {
		pvcontents arg;
		BGET_pvcontents(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) pregcomp pvcontents:\"%s\"\n",
				insn, (char*)arg));
		BSET_pregcomp(PL_op, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_pregcomp(PL_op, \"%s\")\n",
				(char*)arg));
		break;
	    }
	  case INSN_OP_PMFLAGS:		/* 113 */
	    {
		pmflags arg;
		BGET_pmflags(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_pmflags pmflags:%d\n",
				insn, (int)arg));
		BSET_op_pmflags(cPMOP->op_pmflags, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_op_pmflags(cPMOP->op_pmflags, %d)\n",
				(int)arg));
		break;
	    }
	  case 114:		/* 114 */
	    {
		U16 arg;
		PERL_UNUSED_VAR(arg);
		PerlIO_printf(Perl_error_log, "Unsupported bytecode instruction %d (OP_PMPERMFLAGS) at stream offset %d.\n",
	                                  insn, bstate->bs_fdata->next_out);
		if (force)
			BGET_U16(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_pmpermflags U16:%u\n",
				insn, (int)arg));
		DEBUG_v(Perl_deb(aTHX_ "	   cPMOP->op_pmpermflags = %u;\n", (int)arg));
		break;
	    }
	  case 115:		/* 115 */
	    {
		U8 arg;
		PERL_UNUSED_VAR(arg);
		PerlIO_printf(Perl_error_log, "Unsupported bytecode instruction %d (OP_PMDYNFLAGS) at stream offset %d.\n",
	                                  insn, bstate->bs_fdata->next_out);
		if (force)
			BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_pmdynflags U8:%u\n",
				insn, (int)arg));
		DEBUG_v(Perl_deb(aTHX_ "	   cPMOP->op_pmdynflags = %u;\n", (int)arg));
		break;
	    }
	  case INSN_OP_SV:		/* 116 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_sv svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		cSVOP->op_sv = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   cSVOP->op_sv = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_OP_PADIX:		/* 117 */
	    {
		PADOFFSET arg;
		BGET_PADOFFSET(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_padix PADOFFSET:%d\n",
				insn, (int)arg));
		cPADOP->op_padix = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   cPADOP->op_padix = %d;\n", (int)arg));
		break;
	    }
	  case INSN_OP_PV:		/* 118 */
	    {
		pvcontents arg;
		BGET_pvcontents(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_pv pvcontents:\"%s\"\n",
				insn, (char*)arg));
		cPVOP->op_pv = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   cPVOP->op_pv = \"%s\";\n", (char*)arg));
		break;
	    }
	  case INSN_OP_PV_TR:		/* 119 */
	    {
		op_tr_array arg;
		BGET_op_tr_array(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_pv_tr op_tr_array:\"%s\"\n",
				insn, (char*)arg));
		cPVOP->op_pv = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   cPVOP->op_pv = \"%s\";\n", (char*)arg));
		break;
	    }
	  case INSN_OP_REDOOP:		/* 120 */
	    {
		opindex arg;
		BGET_opindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_redoop opindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		cLOOP->op_redoop = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   cLOOP->op_redoop = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_OP_NEXTOP:		/* 121 */
	    {
		opindex arg;
		BGET_opindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_nextop opindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		cLOOP->op_nextop = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   cLOOP->op_nextop = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_OP_LASTOP:		/* 122 */
	    {
		opindex arg;
		BGET_opindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_lastop opindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		cLOOP->op_lastop = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   cLOOP->op_lastop = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_COP_LABEL:		/* 123 */
	    {
		pvindex arg;
		BGET_pvindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) cop_label pvindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_cop_label(cCOP, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_cop_label(cCOP, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_COP_STASHPV:		/* 124 */
	    {
		pvindex arg;
		BGET_pvindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) cop_stashpv pvindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_cop_stashpv(cCOP, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_cop_stashpv(cCOP, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_COP_FILE:		/* 125 */
	    {
		pvindex arg;
		BGET_pvindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) cop_file pvindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_cop_file(cCOP, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_cop_file(cCOP, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case 126:		/* 126 */
	    {
		svindex arg;
		PERL_UNUSED_VAR(arg);
		PerlIO_printf(Perl_error_log, "Unsupported bytecode instruction %d (COP_STASH) at stream offset %d.\n",
	                                  insn, bstate->bs_fdata->next_out);
		if (force)
			BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) cop_stash svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		if (force)
			BSET_cop_stash(cCOP, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_cop_stash(cCOP, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case 127:		/* 127 */
	    {
		svindex arg;
		PERL_UNUSED_VAR(arg);
		PerlIO_printf(Perl_error_log, "Unsupported bytecode instruction %d (COP_FILEGV) at stream offset %d.\n",
	                                  insn, bstate->bs_fdata->next_out);
		if (force)
			BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) cop_filegv svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		if (force)
			BSET_cop_filegv(cCOP, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_cop_filegv(cCOP, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_COP_SEQ:		/* 128 */
	    {
		U32 arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) cop_seq U32:%u\n",
				insn, (int)arg));
		cCOP->cop_seq = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   cCOP->cop_seq = %u;\n", (int)arg));
		break;
	    }
	  case 129:		/* 129 */
	    {
		I32 arg;
		PERL_UNUSED_VAR(arg);
		PerlIO_printf(Perl_error_log, "Unsupported bytecode instruction %d (COP_ARYBASE) at stream offset %d.\n",
	                                  insn, bstate->bs_fdata->next_out);
		if (force)
			BGET_I32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) cop_arybase I32:%d\n",
				insn, (int)arg));
		DEBUG_v(Perl_deb(aTHX_ "	   cCOP->cop_arybase = %d;\n", (int)arg));
		break;
	    }
	  case INSN_COP_LINE:		/* 130 */
	    {
		line_t arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) cop_line line_t:%u\n",
				insn, (int)arg));
		cCOP->cop_line = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   cCOP->cop_line = %u;\n", (int)arg));
		break;
	    }
	  case 131:		/* 131 */
	    {
		svindex arg;
		PERL_UNUSED_VAR(arg);
		PerlIO_printf(Perl_error_log, "Unsupported bytecode instruction %d (COP_IO) at stream offset %d.\n",
	                                  insn, bstate->bs_fdata->next_out);
		if (force)
			BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) cop_io svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		DEBUG_v(Perl_deb(aTHX_ "	   cCOP->cop_io = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_COP_WARNINGS:		/* 132 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) cop_warnings svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_cop_warnings(cCOP, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_cop_warnings(cCOP, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_MAIN_START:		/* 133 */
	    {
		opindex arg;
		BGET_opindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) main_start opindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		PL_main_start = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   PL_main_start = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_MAIN_ROOT:		/* 134 */
	    {
		opindex arg;
		BGET_opindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) main_root opindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		PL_main_root = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   PL_main_root = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_MAIN_CV:		/* 135 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) main_cv svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		*(SV**)&PL_main_cv = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   *(SV**)&PL_main_cv = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_CURPAD:		/* 136 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) curpad svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_curpad(PL_curpad, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_curpad(PL_curpad, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_PUSH_BEGIN:		/* 137 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) push_begin svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_push_begin(PL_beginav, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_push_begin(PL_beginav, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_PUSH_INIT:		/* 138 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) push_init svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_push_init(PL_initav, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_push_init(PL_initav, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_PUSH_END:		/* 139 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) push_end svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_push_end(PL_endav, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_push_end(PL_endav, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_CURSTASH:		/* 140 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) curstash svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		*(SV**)&PL_curstash = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   *(SV**)&PL_curstash = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_DEFSTASH:		/* 141 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) defstash svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		*(SV**)&PL_defstash = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   *(SV**)&PL_defstash = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_DATA:		/* 142 */
	    {
		U8 arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) data U8:%u\n",
				insn, (int)arg));
		BSET_data(none, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_data(none, %u)\n",
				(int)arg));
		break;
	    }
	  case INSN_INCAV:		/* 143 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) incav svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		*(SV**)&GvAV(PL_incgv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   *(SV**)&GvAV(PL_incgv) = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_LOAD_GLOB:		/* 144 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) load_glob svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_load_glob(none, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_load_glob(none, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_REGEX_PADAV:		/* 145 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) regex_padav svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		*(SV**)&PL_regex_padav = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   *(SV**)&PL_regex_padav = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_DOWARN:		/* 146 */
	    {
		U8 arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) dowarn U8:%u\n",
				insn, (int)arg));
		PL_dowarn = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   PL_dowarn = %u;\n", (int)arg));
		break;
	    }
	  case INSN_COMPPAD_NAME:		/* 147 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) comppad_name svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		*(SV**)&PL_comppad_name = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   *(SV**)&PL_comppad_name = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_XGV_STASH:		/* 148 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xgv_stash svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		*(SV**)&GvSTASH(bstate->u.bs_sv) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   *(SV**)&GvSTASH(bstate->u.bs_sv) = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_SIGNAL:		/* 149 */
	    {
		strconst arg;
		BGET_strconst(arg, 0);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) signal strconst:\"%s\"\n",
				insn, (char*)arg));
		BSET_signal(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_signal(bstate->u.bs_sv, \"%s\")\n",
				(char*)arg));
		break;
	    }
	  case 150:		/* 150 */
	    {
		svindex arg;
		PERL_UNUSED_VAR(arg);
		PerlIO_printf(Perl_error_log, "Unsupported bytecode instruction %d (FORMFEED) at stream offset %d.\n",
	                                  insn, bstate->bs_fdata->next_out);
		if (force)
			BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) formfeed svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		DEBUG_v(Perl_deb(aTHX_ "	   PL_formfeed = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case 151:		/* 151 */
	    {
		U8 arg;
		PERL_UNUSED_VAR(arg);
		PerlIO_printf(Perl_error_log, "Unsupported bytecode instruction %d (OP_LATEFREE) at stream offset %d.\n",
	                                  insn, bstate->bs_fdata->next_out);
		if (force)
			BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_latefree U8:%u\n",
				insn, (int)arg));
		DEBUG_v(Perl_deb(aTHX_ "	   PL_op->op_latefree = %u;\n", (int)arg));
		break;
	    }
	  case 152:		/* 152 */
	    {
		U8 arg;
		PERL_UNUSED_VAR(arg);
		PerlIO_printf(Perl_error_log, "Unsupported bytecode instruction %d (OP_LATEFREED) at stream offset %d.\n",
	                                  insn, bstate->bs_fdata->next_out);
		if (force)
			BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_latefreed U8:%u\n",
				insn, (int)arg));
		DEBUG_v(Perl_deb(aTHX_ "	   PL_op->op_latefreed = %u;\n", (int)arg));
		break;
	    }
	  case 153:		/* 153 */
	    {
		U8 arg;
		PERL_UNUSED_VAR(arg);
		PerlIO_printf(Perl_error_log, "Unsupported bytecode instruction %d (OP_ATTACHED) at stream offset %d.\n",
	                                  insn, bstate->bs_fdata->next_out);
		if (force)
			BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_attached U8:%u\n",
				insn, (int)arg));
		DEBUG_v(Perl_deb(aTHX_ "	   PL_op->op_attached = %u;\n", (int)arg));
		break;
	    }
	  case INSN_OP_REFLAGS:		/* 154 */
	    {
		U32 arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_reflags U32:%u\n",
				insn, (int)arg));
		RX_EXTFLAGS(PM_GETRE(cPMOP)) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   RX_EXTFLAGS(PM_GETRE(cPMOP)) = %u;\n", (int)arg));
		break;
	    }
	  case INSN_GV_FETCHPVN_FLAGS:		/* 157 */
	    {
		U32 arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) gv_fetchpvn_flags U32:%u\n",
				insn, (int)arg));
		BSET_gv_fetchpvn_flags(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_gv_fetchpvn_flags(bstate->u.bs_sv, %u)\n",
				(int)arg));
		break;
	    }
	  case INSN_XIO_IFP:		/* 158 */
	    {
		char arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xio_ifp char:%u\n",
				insn, (int)arg));
		BSET_xio_ifp(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_xio_ifp(bstate->u.bs_sv, %u)\n",
				(int)arg));
		break;
	    }
	  case INSN_XPVSHARED:		/* 159 */
	    {
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xpvshared\n", insn));
		BSET_xpvshared(bstate->u.bs_sv);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_xpvshared(bstate->u.bs_sv)\n"));
		break;
	    }
	  case INSN_NEWPADLX:		/* 160 */
	    {
		U8 arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) newpadlx U8:%u\n",
				insn, (int)arg));
		BSET_newpadlx(bstate->u.bs_padl, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_newpadlx(bstate->u.bs_padl, %u ix:%d)\n",
				(int)arg, bstate->bs_ix-1));
		break;
	    }
	  case INSN_PADL_NAME:		/* 161 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) padl_name svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_padl_name(bstate->u.bs_padl, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_padl_name(bstate->u.bs_padl, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_PADL_SYM:		/* 162 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) padl_sym svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_padl_sym(bstate->u.bs_padl, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_padl_sym(bstate->u.bs_padl, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_XCV_NAME_HEK:		/* 163 */
	    {
		pvindex arg;
		BGET_pvindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) xcv_name_hek pvindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_xcv_name_hek(bstate->u.bs_sv, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_xcv_name_hek(bstate->u.bs_sv, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_OP_SLABBED:		/* 164 */
	    {
		U8 arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_slabbed U8:%u\n",
				insn, (int)arg));
		PL_op->op_slabbed = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   PL_op->op_slabbed = %u;\n", (int)arg));
		break;
	    }
	  case INSN_OP_SAVEFREE:		/* 165 */
	    {
		U8 arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_savefree U8:%u\n",
				insn, (int)arg));
		PL_op->op_savefree = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   PL_op->op_savefree = %u;\n", (int)arg));
		break;
	    }
	  case INSN_OP_STATIC:		/* 166 */
	    {
		U8 arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_static U8:%u\n",
				insn, (int)arg));
		PL_op->op_static = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   PL_op->op_static = %u;\n", (int)arg));
		break;
	    }
	  case INSN_OP_FOLDED:		/* 167 */
	    {
		U8 arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_folded U8:%u\n",
				insn, (int)arg));
		PL_op->op_folded = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   PL_op->op_folded = %u;\n", (int)arg));
		break;
	    }
	  case INSN_OP_MORESIB:		/* 168 */
	    {
		U8 arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) op_moresib U8:%u\n",
				insn, (int)arg));
		PL_op->op_moresib = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   PL_op->op_moresib = %u;\n", (int)arg));
		break;
	    }
	  case INSN_NEWPADNLX:		/* 169 */
	    {
		U8 arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) newpadnlx U8:%u\n",
				insn, (int)arg));
		BSET_newpadnlx(bstate->u.bs_padnl, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_newpadnlx(bstate->u.bs_padnl, %u ix:%d)\n",
				(int)arg, bstate->bs_ix-1));
		break;
	    }
	  case INSN_PADL_OUTID:		/* 170 */
	    {
		U32 arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) padl_outid U32:%u\n",
				insn, (int)arg));
		((PADLIST*)bstate->u.bs_padl)->xpadl_outid = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   ((PADLIST*)bstate->u.bs_padl)->xpadl_outid = %u;\n", (int)arg));
		break;
	    }
	  case INSN_PADL_ID:		/* 171 */
	    {
		U32 arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) padl_id U32:%u\n",
				insn, (int)arg));
		((PADLIST*)bstate->u.bs_padl)->xpadl_id = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   ((PADLIST*)bstate->u.bs_padl)->xpadl_id = %u;\n", (int)arg));
		break;
	    }
	  case INSN_PADNL_PUSH:		/* 172 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) padnl_push svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		BSET_padnl_push(bstate->u.bs_padnl, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_padnl_push(bstate->u.bs_padnl, 0x%lx)\n",
				PTR2UV(arg)));
		break;
	    }
	  case INSN_PADNL_MAXNAMED:		/* 173 */
	    {
		U32 arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) padnl_maxnamed U32:%u\n",
				insn, (int)arg));
		PadnamelistMAXNAMED(bstate->u.bs_padnl) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   PadnamelistMAXNAMED(bstate->u.bs_padnl) = %u;\n", (int)arg));
		break;
	    }
	  case INSN_PADNL_REFCNT:		/* 174 */
	    {
		U32 arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) padnl_refcnt U32:%u\n",
				insn, (int)arg));
		PadnamelistREFCNT(bstate->u.bs_padnl) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   PadnamelistREFCNT(bstate->u.bs_padnl) = %u;\n", (int)arg));
		break;
	    }
	  case INSN_NEWPADNX:		/* 175 */
	    {
		strconst arg;
		BGET_strconst(arg, 0);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) newpadnx strconst:\"%s\"\n",
				insn, (char*)arg));
		BSET_newpadnx(bstate->u.bs_padn, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_newpadnx(bstate->u.bs_padn, \"%s\" ix:%d)\n",
				(char*)arg, bstate->bs_ix-1));
		break;
	    }
	  case INSN_PADN_STASH:		/* 176 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) padn_stash svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		*(SV**)PadnameOURSTASH(bstate->u.bs_padn) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   *(SV**)PadnameOURSTASH(bstate->u.bs_padn) = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_PADN_TYPE:		/* 177 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) padn_type svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		*(SV**)PadnameTYPE(bstate->u.bs_padn) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   *(SV**)PadnameTYPE(bstate->u.bs_padn) = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_PADN_SEQ_LOW:		/* 178 */
	    {
		U32 arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) padn_seq_low U32:%u\n",
				insn, (int)arg));
		COP_SEQ_RANGE_LOW(bstate->u.bs_padn) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   COP_SEQ_RANGE_LOW(bstate->u.bs_padn) = %u;\n", (int)arg));
		break;
	    }
	  case INSN_PADN_SEQ_HIGH:		/* 179 */
	    {
		U32 arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) padn_seq_high U32:%u\n",
				insn, (int)arg));
		COP_SEQ_RANGE_HIGH(bstate->u.bs_padn) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   COP_SEQ_RANGE_HIGH(bstate->u.bs_padn) = %u;\n", (int)arg));
		break;
	    }
	  case INSN_PADN_REFCNT:		/* 180 */
	    {
		U32 arg;
		BGET_U32(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) padn_refcnt U32:%u\n",
				insn, (int)arg));
		PadnameREFCNT(bstate->u.bs_padn) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   PadnameREFCNT(bstate->u.bs_padn) = %u;\n", (int)arg));
		break;
	    }
	  case INSN_PADN_PV:		/* 181 */
	    {
		strconst arg;
		BGET_strconst(arg, 0);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) padn_pv strconst:\"%s\"\n",
				insn, (char*)arg));
		BSET_padn_pv(bstate->u.bs_padn, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_padn_pv(bstate->u.bs_padn, \"%s\")\n",
				(char*)arg));
		break;
	    }
	  case INSN_PADN_FLAGS:		/* 182 */
	    {
		U8 arg;
		BGET_U8(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) padn_flags U8:%u\n",
				insn, (int)arg));
		PadnameFLAGS(bstate->u.bs_padn) = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   PadnameFLAGS(bstate->u.bs_padn) = %u;\n", (int)arg));
		break;
	    }
	  case INSN_UNOP_AUX:		/* 183 */
	    {
		strconst arg;
		BGET_strconst(arg, 0);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) unop_aux strconst:\"%s\"\n",
				insn, (char*)arg));
		BSET_unop_aux(cUNOP_AUX->op_aux, arg);
		DEBUG_v(Perl_deb(aTHX_ "	   BSET_unop_aux(cUNOP_AUX->op_aux, \"%s\" ix:%d)\n",
				(char*)arg, bstate->bs_ix-1));
		break;
	    }
	  case INSN_METHOP_METHSV:		/* 184 */
	    {
		svindex arg;
		BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) methop_methsv svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		cMETHOPx(PL_op)->op_u.op_meth_sv = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   cMETHOPx(PL_op)->op_u.op_meth_sv = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case 185:		/* 185 */
	    {
		svindex arg;
		PERL_UNUSED_VAR(arg);
		PerlIO_printf(Perl_error_log, "Unsupported bytecode instruction %d (METHOP_RCLASS) at stream offset %d.\n",
	                                  insn, bstate->bs_fdata->next_out);
		if (force)
			BGET_svindex(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) methop_rclass svindex:0x%lx, ix:%d\n",
				insn, PTR2UV(arg), (int)ix));
		DEBUG_v(Perl_deb(aTHX_ "	   cMETHOPx(PL_op)->op_rclass_sv = 0x%lx;\n", PTR2UV(arg)));
		break;
	    }
	  case INSN_METHOP_RCLASS:		/* 186 */
	    {
		PADOFFSET arg;
		BGET_PADOFFSET(arg);
		DEBUG_v(Perl_deb(aTHX_ "(insn %3d) methop_rclass PADOFFSET:%d\n",
				insn, (int)arg));
		cMETHOPx(PL_op)->op_rclass_targ = arg;
		DEBUG_v(Perl_deb(aTHX_ "	   cMETHOPx(PL_op)->op_rclass_targ = %d;\n", (int)arg));
		break;
	    }
	    default:
	      Perl_croak(aTHX_ "Illegal bytecode instruction %d at stream offset %d.\n",
                         insn, bstate->bs_fdata->next_out);
	      /* NOTREACHED */
	  }
	  /* debop is not public in 5.10.0 on strict platforms like mingw and MSVC, cygwin is fine. */
#if defined(DEBUG_t_TEST_) && !defined(_MSC_VER) && !defined(__MINGW32__) && !defined(AIX)
          if (PL_op && DEBUG_t_TEST_)
              /* GV without the cGVOPo_gv initialized asserts. We need to skip newopx */
              if ((insn != INSN_NEWOPX) && (insn != INSN_NEWOP) && (PL_op->op_type != OP_GV)) debop(PL_op);
#endif
        }
    }
    return 0;
}

/* ex: set ro: */
